@@ -5,57 +5,62 @@ use Exporter;
 use YAML::Syck ();
 
 BEGIN {
-    $VERSION    = '1.23';
-    @EXPORT_OK  = qw( Load Dump LoadFile DumpFile DumpInto );
-    @ISA        = 'Exporter';
-    *Load       = \&YAML::Syck::LoadJSON;
-    *Dump       = \&YAML::Syck::DumpJSON;
+    $VERSION   = '1.25';
+    @EXPORT_OK = qw( Load Dump LoadFile DumpFile DumpInto );
+    @ISA       = 'Exporter';
+    *Load      = \&YAML::Syck::LoadJSON;
+    *Dump      = \&YAML::Syck::DumpJSON;
 }
 
 sub DumpFile {
     my $file = shift;
     if ( YAML::Syck::_is_glob($file) ) {
-        my $err = YAML::Syck::DumpJSONFile($_[0], $file);
+        my $err = YAML::Syck::DumpJSONFile( $_[0], $file );
         if ($err) {
-            $! = 0+$err;
+            $! = 0 + $err;
             die "Error writing to filehandle $file: $!\n";
         }
-    } else {
-        open(my $fh, '>',  $file) or die "Cannot write to $file: $!";
-        my $err = YAML::Syck::DumpJSONFile($_[0], $fh);
+    }
+    else {
+        open( my $fh, '>', $file ) or die "Cannot write to $file: $!";
+        my $err = YAML::Syck::DumpJSONFile( $_[0], $fh );
         if ($err) {
-            $! = 0+$err;
+            $! = 0 + $err;
             die "Error writing to file $file: $!\n";
         }
         close $fh
-            or die "Error writing to file $file: $!\n";
+          or die "Error writing to file $file: $!\n";
     }
     return 1;
 }
 
-
 sub LoadFile {
     my $file = shift;
     if ( YAML::Syck::_is_glob($file) ) {
-        YAML::Syck::LoadJSON(do { local $/; <$file> });
+        YAML::Syck::LoadJSON(
+            do { local $/; <$file> }
+        );
     }
     else {
-        if(!-e $file || -z $file) {
-	    die("'$file' is non-existent or empty");
-	}
-        open(my $fh, '<', $file) or die "Cannot read from $file: $!";
-        YAML::Syck::LoadJSON(do { local $/; <$fh> });
+        if ( !-e $file || -z $file ) {
+            die("'$file' is non-existent or empty");
+        }
+        open( my $fh, '<', $file ) or die "Cannot read from $file: $!";
+        YAML::Syck::LoadJSON(
+            do { local $/; <$fh> }
+        );
     }
 }
 
 sub DumpInto {
     my $bufref = shift;
-    (ref $bufref) or die "DumpInto not given reference to output buffer\n";
-    YAML::Syck::DumpJSONInto($_[0], $bufref);
+    ( ref $bufref ) or die "DumpInto not given reference to output buffer\n";
+    YAML::Syck::DumpJSONInto( $_[0], $bufref );
     1;
 }
 
 $JSON::Syck::ImplicitTyping  = 1;
+$JSON::Syck::MaxDepth        = 512;
 $JSON::Syck::Headless        = 1;
 $JSON::Syck::ImplicitUnicode = 0;
 $JSON::Syck::SingleQuote     = 0;
@@ -138,6 +143,13 @@ as in:
   Perl (UTF-8 bytes)   => JSON (UTF-8 flagged)
   Perl (UTF-8 flagged) => JSON (UTF-8 flagged)
 
+By default, JSON::Syck::Dump will only transverse up to 512 levels of
+a datastructure in order to avoid an infinite loop when it is
+presented with an circular reference.
+
+However, you set C<$JSON::Syck::MaxLevels> to a larger value if you
+have very complex structures.
+
 Unfortunately, there's no implicit way to dump Perl UTF-8 flagged data
 structure to utf-8 encoded JSON. To do this, simply use Encode module, e.g.:
 
